@@ -1,11 +1,4 @@
-use crate::*;
-use serde::Deserialize;
-
-#[derive(Deserialize)]
-struct Height {
-    /// The current block height of the chain.
-    pub height: u64,
-}
+use crate::{models::Height, *};
 
 /// Get the current height of the blockchain
 pub async fn height(client: &Client) -> Result<u64> {
